@@ -3,7 +3,7 @@ http://github.com/tiddlyweb/chrjs/raw/master/main.js
 ***/
 //{{{
 // TiddlyWeb adaptor
-// v0.10.3
+// v0.10.5
 //
 // TODO:
 // * ensure all routes are supported
@@ -31,7 +31,7 @@ tiddlyweb = {
 // host (optional) is the URI of the originating TiddlyWeb instance
 tiddlyweb.Resource = function(type, host) {
 	if(arguments.length) { // initialization
-		this._type = type; // XXX: somewhat redundant, as it generally corresponds to class name
+		this._type = type;
 		if(host !== false) {
 			this.host = host !== undefined ? host.replace(/\/$/, "") : null;
 		}
@@ -167,15 +167,18 @@ var TiddlerCollection = function(container, tiddler) {
 TiddlerCollection.prototype = new tiddlyweb.Collection();
 $.extend(TiddlerCollection.prototype, {
 	parse: function(data) {
-		var host = this.container.host;
-		return $.map(data, function(item, i) { // TODO: DRY (cf. Tiddler's parse method)
-			var tiddler = new tiddlyweb.Tiddler(item.title);
-			tiddler.bag = new tiddlyweb.Bag(item.bag, host);
-			delete item.bag;
-			if(item.recipe) {
-				tiddler.recipe = new tiddlyweb.Recipe(item.recipe, host);
-				delete item.recipe;
+		var container = this.container;
+		return $.map(data, function(item, i) {
+			var tiddler = new tiddlyweb.Tiddler(item.title, container);
+			var bag = item.bag;
+			tiddler = tiddlyweb.Tiddler.prototype.parse.apply(tiddler, [item]);
+			if(!tiddler.bag && bag) { // XXX: bag always present!?
+				tiddler.bag = new tiddlyweb.Bag(bag, container.host);
 			}
+			if(!tiddler.recipe && item.recipe) {
+				tiddler.recipe = new tiddlyweb.Recipe(item.recipe, container.host);
+			}
+			delete item.recipe;
 			return $.extend(tiddler, item);
 		});
 	},
@@ -195,6 +198,23 @@ $.extend(TiddlerCollection.prototype, {
 	}
 });
 
+tiddlyweb.Search = function(query, host) {
+	tiddlyweb.Collection.apply(this, ["search", host]);
+	this.query = query;
+};
+tiddlyweb.Search.prototype = new tiddlyweb.Collection();
+$.extend(tiddlyweb.Search.prototype, {
+	parse: function(data) {
+		this.container = { // XXX: hacky
+			_type: "bag",
+			host: this.host
+		};
+		var tiddlers = TiddlerCollection.prototype.parse.apply(this, arguments);
+		delete this.container;
+		return tiddlers;
+	}
+});
+
 // title is the name of the tiddler
 // container (optional) is an instance of either Bag or Recipe
 tiddlyweb.Tiddler = function(title, container) {
@@ -226,6 +246,7 @@ $.extend(tiddlyweb.Tiddler.prototype, {
 		var container = this.bag || this.recipe;
 		tiddler.bag = new tiddlyweb.Bag(data.bag, container.host);
 		delete data.bag;
+		delete data.recipe;
 		tiddler.created = convertTimestamp(data.created);
 		delete data.created;
 		tiddler.modified = convertTimestamp(data.modified);
